You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@marmotta.apache.org by wi...@apache.org on 2014/03/18 16:37:15 UTC

[3/6] git commit: MARMOTTA-438: switch the approach from one file per test case to a single one (manually extracted with RDFa Distiller and cached locally)

MARMOTTA-438: switch the approach from one file per test case to a single one (manually extracted with RDFa Distiller and cached locally)


Project: http://git-wip-us.apache.org/repos/asf/marmotta/repo
Commit: http://git-wip-us.apache.org/repos/asf/marmotta/commit/6490c9a9
Tree: http://git-wip-us.apache.org/repos/asf/marmotta/tree/6490c9a9
Diff: http://git-wip-us.apache.org/repos/asf/marmotta/diff/6490c9a9

Branch: refs/heads/ldp
Commit: 6490c9a99f342d350f84d65a3425ec9dfc6db016
Parents: 7097862
Author: Sergio Fernández <wi...@apache.org>
Authored: Mon Mar 17 17:17:24 2014 +0100
Committer: Sergio Fernández <wi...@apache.org>
Committed: Mon Mar 17 17:17:24 2014 +0100

----------------------------------------------------------------------
 .../testsuite/LdpAbstractTestSuite.java         |   20 +-
 .../testsuite/LDP-Test-Cases-WD-20140317.ttl    | 1269 ++++++++++++++++++
 2 files changed, 1280 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/marmotta/blob/6490c9a9/platform/marmotta-ldp/src/test/java/org/apache/marmotta/platform/ldp/webservices/testsuite/LdpAbstractTestSuite.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-ldp/src/test/resources/testsuite/LDP-Test-Cases-WD-20140317.ttl b/platform/marmotta-ldp/src/test/resources/testsuite/LDP-Test-Cases-WD-20140317.ttl
new file mode 100644
index 0000000..1a33219
--- /dev/null
+++ b/platform/marmotta-ldp/src/test/resources/testsuite/LDP-Test-Cases-WD-20140317.ttl
@@ -0,0 +1,1269 @@
+@prefix dc: <http://purl.org/dc/terms/> .
+@prefix foaf: <http://xmlns.com/foaf/0.1/> .
+@prefix ht: <http://www.w3.org/2011/http#> .
+@prefix owl: <http://www.w3.org/2002/07/owl#> .
+@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
+@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
+@prefix td: <http://www.w3.org/2006/03/test-description#> .
+@prefix tn: <http://ldp.example.org/NewTestDefinitions#> .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1> a td:TestCase;
+    rdfs:label "TC-C1";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-A1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-A2-Response-1-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-RQ1-GET-LDPC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a GET request on an LDPC.";
+    dc:title "GET on an LDPC";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I2-S-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I3-P-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-O1-Response-1-GET>;
+    td:precondition "The LDP server contains an LDPC at <LDPC URI>",
+        "The membership predicate used by the LDPC is identified by  <P URI>",
+        "The membership subject used by the LDPC is identified by  <S URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "5.2.7 The representation of a LDPC MUST have rdf:type of ldp:Container, [...].";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.2.5.1 For a given triple T with a subject C of the LDPC and predicate of ldp:membershipPredicate, the object MUST be the URI of the membership predicate P used to indicate membership to the linked to LDPC, [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.2.5.2 For a given triple T with a subject C of the LDPC and predicate of ldp:membershipPredicateInverse, the object MUST be the URI of the membership predicate P used to indicate membership to the linked to LDPC, [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.2.8 LDPR server responses MUST use entity tags (either weak or strong ones) as response ETag header values.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.3.1 LDPR servers MUST support the HTTP GET Method for LDPRs.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.2.5 An LDPC representation MUST contain exactly one triple whose subject is the LDPC URI, and whose predicate is either ldp:membershipPredicate or ldp:membershipPredicateInverse. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.2.4 An LDPC representation MUST contain exactly one triple whose subject is the LDPC URI, whose predicate is the ldp:membershipSubject, and whose object is the LDPC's membership subject URI.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10> a td:TestCase;
+    rdfs:label "TC-C10";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-A1-Response-1-OPTIONS>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-RQ1-OPTIONS-LDPC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making an OPTIONS request on an LDPC.";
+    dc:title "OPTIONS on an LDPC";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-I1-LDPC-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-RP1-Response-1-OPTIONS>;
+    td:precondition "The LDP server contains an LDPC at <LDPC URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.9.2 LDPR servers MUST indicate their support for HTTP Methods by responding to a HTTP OPTIONS request on the LDPR’s URL with the HTTP Method tokens in the HTTP response header Allow.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.9.1 LDPR servers MUST support the HTTP OPTIONS method.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11> a td:TestCase;
+    rdfs:label "TC-C11";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A2-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A3-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A4-Response-2-POST>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A5-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A6-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A7-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A8-Response-4-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ1-GET-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ2-POST-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ3-GET-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ4-GET-LOC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ4-TEST-CONTAINER> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a POST request of an LDPC on an LDPC as a sub-container.";
+    dc:title "POST an LDPC on an LDPC as a sub-container";
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I2-LDPC2-REP>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I3-S-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I4-P-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O2-Response-2-POST>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O3-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O4-Response-4-GET>;
+    td:precondition "<LDPC2 representation> is a valid representation for a sub-container to be created in the LDPC",
+        "<LDPC2 representation> is in text/turtle",
+        "<LDPC2 representation> uses null relative URI as the entity in the request body",
+        "The LDP server contains an LDPC at <LDPC URI>",
+        "The LDP server does not desire to direct the user agent to retrieve a cacheable resource Would this be cachable?",
+        "The LDPC at <LDPC URI> allows POST",
+        "The membership predicate used by the LDPC is identified by  <P URI>",
+        "The membership subject used by the LDPC is identified by  <S URI>";
+    td:reviewStatus td:unreviewed .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12> a td:TestCase;
+    rdfs:label "TC-C12";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A2-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A3-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A4-Response-2-POST>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A5-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A6-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A7-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A8-Response-4-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ1-GET-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ2-POST-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ3-GET-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ4-GET-LOC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ4-TEST-CONTAINER> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a POST request of an LDPC on an LDPC as a sub-container.";
+    dc:title "POST an LDPC on an LDPC as a sub-container";
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I2-LDPC2-REP>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I3-S-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I4-P-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O2-Response-2-POST>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O3-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O4-Response-4-GET>;
+    td:precondition "<LDPC2 representation> is a valid representation for a sub-container to be stored in the LDPC",
+        "<LDPC2 representation> is in text/turtle",
+        "<LDPC2 representation> uses null relative URI as the entity in the request body",
+        "The LDP server contains an LDPC at <LDPC URI>",
+        "The LDP server does not desire to direct the user agent to retrieve a cacheable resource Would this be cachable?",
+        "The LDPC at <LDPC URI> allows POST",
+        "The membership predicate used by the LDPC is identified by  <P URI>",
+        "The membership subject used by the LDPC is identified by  <S URI>";
+    td:reviewStatus td:unreviewed .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3> a td:TestCase;
+    rdfs:label "TC-C3";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-A1-Response-1-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-RQ1-GET-LDPC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a GET request on an non-existing LDPC.";
+    dc:title "GET on a non-existing LDPC";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-I1-LDPC-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-O1-Response-1-GET>;
+    td:precondition "The LDP server does not contain an LDPC at <LDPC URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.6.1 LDPR servers MUST remove the resource identified by the Request-URI. After a successful HTTP DELETE, a subsequent HTTP GET on the same Request-URI MUST result in a 404 (Not found) or 410 (Gone) status code.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6> a td:TestCase;
+    rdfs:label "TC-C6";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-A1-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-A2-Response-1-DELETE>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-RQ1-DELETE-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-RQ2-GET-LDPC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a DELETE request on an LDPC.";
+    dc:title "DELETE on an LDPC";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-I1-LDPC-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-O1-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-O2-Response-2-GET>;
+    td:precondition "The LDP server contains an LDPC at <LDPC URI>",
+        "The LDPC at <LDPC URI> allows DELETE";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.6.1 LDPR servers MUST remove the resource identified by the Request-URI. After a successful HTTP DELETE, a subsequent HTTP GET on the same Request-URI MUST result in a 404 (Not found) or 410 (Gone) status code.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7> a td:TestCase;
+    rdfs:label "TC-C7";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A1-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A2-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A3-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A4-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A5-Response-3-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ1-DELETE-LDPR-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ2-GET-LDPR-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ3-GET-LDPC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a DELETE request on an LDPR in an LDPC.";
+    dc:title "DELETE on an LDPR in an LDPC";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I2-LDPR-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I3-S-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I4-P-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-O1-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-O2-Response-2-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-O3-Response-3-GET>;
+    td:precondition "The LDP server contains an LDPC at <LDPC URI>",
+        "The LDP server contains an LDPR at <LDPR URI>",
+        "The LDPR at <LDPR URI> allows DELETE",
+        "The LDPR is a member of the LDPC",
+        "The LDPR was originally created by the LDPC",
+        "The membership predicate used by the LDPC is identified by  <P URI>",
+        "The membership subject used by the LDPC is identified by  <S URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "5.6.2 When the LDPC server successfully completes the DELETE request on a LDPC, it MUST remove any membership triples associated with the LDPC as indicated by the canonical Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8> a td:TestCase;
+    rdfs:label "TC-C8";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-A1-Response-1-HEAD>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-RQ1-HEAD-LDPC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a HEAD request on an LDPC.";
+    dc:title "HEAD on an LDPC";
+    rdfs:seeAlso <http://tools.ietf.org/html/rfc2616>,
+        <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-I1-LDPC-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-O1-Response-1-HEAD>;
+    td:precondition "The LDP server contains an LDPC at <LDPC URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "9.4 The HEAD method is identical to GET except that the server MUST NOT return a message-body in the response.";
+            rdfs:seeAlso <http://tools.ietf.org/html/rfc2616> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.7.1 LDPR servers MUST support the HTTP HEAD method.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9> a td:TestCase;
+    rdfs:label "TC-C9";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A2-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A3-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A4-Response-2-POST>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A5-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A6-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A7-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A8-Response-4-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ1-GET-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ2-POST-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ3-GET-LDPC-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ4-GET-LOC-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a POST request of an LDPR on an LDPC.";
+    dc:title "POST an LDPR on an LDPC";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I2-LDPR-REP>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I3-S-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I4-P-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O1-Response-1-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O2-Response-2-POST>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O3-Response-3-GET>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O4-Response-4-GET>;
+    td:precondition "<LDPR representation> is a valid representation for a resource to be created in the LDPC",
+        "<LDPR representation> is in text/turtle",
+        "<LDPR representation> uses null relative URI as the entity in the request body",
+        "The LDP server contains an LDPC at <LDPC URI>",
+        "The LDP server does not desire to direct the user agent to retrieve a cacheable resource",
+        "The LDPC at <LDPC URI> allows POST",
+        "The membership predicate used by the LDPC is identified by  <P URI>",
+        "The membership subject used by the LDPC is identified by  <S URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "5.4.1 [...] If the resource was created successfully, LDPC servers MUST respond with status code 201 (Created) and the Location header set to the new resource’s URL. [...] ";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.4.4 For servers that support create, LDPC servers MUST create an LDPR from a RDF representation in the request entity body. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.4.2 After a successful HTTP POST request to a LDPC, the new resource MUST appear as a member of the LDPC until the new resource is deleted or removed by other methods. [...] ";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "5.4.5 LDPC servers MUST accept a request entity body with a request header of Content-Type with value of text/turtle. ";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1> a td:TestCase;
+    rdfs:label "TC-R1";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-A1-Response-1-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-RQ1-GET-LDPR-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a GET request on an existing LDPR.";
+    dc:title "GET on an LDPR";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-I1-LDPR-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-O1-Response-1-GET>;
+    td:precondition "The LDP server contains an LDPR at <LDPR URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.2.8 LDPR server responses MUST use entity tags (either weak or strong ones) as response ETag header values.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.3.1 LDPR servers MUST support the HTTP GET Method for LDPRs.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3> a td:TestCase;
+    rdfs:label "TC-R3";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-A1-Response-1-GET>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-RQ1-GET-LDPR-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a GET request on a non-existing LDPR.";
+    dc:title "GET on a non-existing LDPR";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-I1-LDPR-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-O1-Response-1-GET>;
+    td:precondition "The LDP server does not contain an LDPR at <LDPR URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.6.1 LDPR servers MUST remove the resource identified by the Request-URI. After a successful HTTP DELETE, a subsequent HTTP GET on the same Request-URI MUST result in a 404 (Not found) or 410 (Gone) status code.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6> a td:TestCase;
+    rdfs:label "TC-R6";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-A1-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-A2-Response-1-DELETE>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-RQ1-DELETE-LDPR-URI> <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-RQ2-GET-LDPR-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a DELETE request on an LDPR.";
+    dc:title "DELETE on an LDPR";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-I1-LDPR-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-O1-Response-1-DELETE>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-O2-Response-2-GET>;
+    td:precondition "The LDP server contains an LDPR at <LDPR URI>",
+        "The LDPR at <LDPR URI> allows DELETE";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.6.1 LDPR servers MUST remove the resource identified by the Request-URI. After a successful HTTP DELETE, a subsequent HTTP GET on the same Request-URI MUST result in a 404 (Not found) or 410 (Gone) status code.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7> a td:TestCase;
+    rdfs:label "TC-R7";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-A1-Response-1-HEAD>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-RQ1-HEAD-LDPR-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making a HEAD request on an LDPR.";
+    dc:title "HEAD on an LDPR";
+    rdfs:seeAlso <http://tools.ietf.org/html/rfc2616>,
+        <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-I1-LDPR-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-O1-Response-1-HEAD>;
+    td:precondition "The LDP server contains an LDPR at <LDPR URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.2.10 LDPR servers MUST advertise their LDP support by exposing a HTTP Link header with a target URI of http://www.w3.org/ns/ldp/Resource, and a link relation type of type (that is, rel=\"type\") in all responses to requests made to the resource's HTTP Request-URI. [...]";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "9.4 The HEAD method is identical to GET except that the server MUST NOT return a message-body in the response.";
+            rdfs:seeAlso <http://tools.ietf.org/html/rfc2616> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.7.1 LDPR servers MUST support the HTTP HEAD method.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8> a td:TestCase;
+    rdfs:label "TC-R8";
+    tn:testAssertion <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-A1-Response-1-OPTIONS>;
+    tn:testProcess ( <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-RQ1-OPTIONS-LDPR-URI> );
+    dc:contributor <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro>;
+    dc:description "Tests making an OPTIONS request on an LDPR.";
+    dc:title "OPTIONS on an LDPR";
+    rdfs:seeAlso <http://www.w3.org/TR/ldp/>;
+    td:input <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-I1-LDPR-URI>;
+    td:output <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-RP1-Response-1-OPTIONS>;
+    td:precondition "The LDP server contains an LDPR at <LDPR URI>";
+    td:reviewStatus td:unreviewed;
+    td:specificationReference [ a tn:Excerpt;
+            tn:includesText "4.9.1 LDPR servers MUST support the HTTP OPTIONS method.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ],
+        [ a tn:Excerpt;
+            tn:includesText "4.9.2 LDPR servers MUST indicate their support for HTTP Methods by responding to a HTTP OPTIONS request on the LDPR’s URL with the HTTP Method tokens in the HTTP response header Allow.";
+            rdfs:seeAlso <http://www.w3.org/TR/ldp/> ] .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC1-O1-Response-1-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-A2-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC1-O1-Response-1-GET>;
+    dc:description """
+          
+            [message-body] contains <LDPC URI> rdf:type ldp:Container .
+            [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+            [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+          
+        """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I2-S-URI> a tn:TestInput;
+    dc:description "The URI of an RDF resource.";
+    dc:title "<S URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I3-P-URI> a tn:TestInput;
+    dc:description "The URI of an RDF property.";
+    dc:title "<P URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-RQ1-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title "<Response 1 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-A1-Response-1-OPTIONS> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC10-O1-Response-1-OPTIONS>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx 
+            [entity-header].Allow exists
+          
+        """;
+    dc:title "OPTIONS correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-RP1-Response-1-OPTIONS> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-RQ1-OPTIONS-LDPC-URI>;
+    dc:description "The response of the OPTIONS request in step 1.";
+    dc:title "<Response 1 OPTIONS>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O1-Response-1-GET>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 2xx
+                      [response-header].ETag exists
+                      [response-header].Link: val=<LDP1ResourceInteraction>; rel=profile
+                  
+              """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A2-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O1-Response-1-GET>;
+    dc:description """
+                  
+                      [message-body] contains <LDPC URI> rdf:type ldp:Container .
+                      [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+                      [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+                  
+              """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A3-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O1-Response-1-GET>;
+    dc:description """
+                  
+                      [message-body] does not contain <S URI> <P URI> <Response 2 POST>.[response-header].Location .
+                  
+              """;
+    dc:title "container does not have the to-be-created member" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A4-Response-2-POST> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O2-Response-2-POST>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 201
+                      [response-header].Location exists
+                      [response-header].Link: val=<LDP1ContainerInteraction>; rel=profile
+                  
+              """;
+    dc:title "POST correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A5-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O3-Response-3-GET>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 2xx
+                      [response-header].ETag exists
+                      [response-header].Link: val=<LDP1ContainerInteraction>; rel=profile
+                  
+              """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A6-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O3-Response-3-GET>;
+    dc:description """
+                  
+                      [message-body] contains <LDPC URI> rdf:type ldp:Container .
+                      [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+                      [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+                  
+              """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A7-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O3-Response-3-GET>;
+    dc:description """
+                  
+                      [message-body] contains <S URI> <P URI> <Response 2 POST>.[response-header].Location .
+                  
+              """;
+    dc:title "container has member" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-A8-Response-4-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC11-O4-Response-4-GET>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 2xx
+                      [response-header].ETag exists
+                      [response-header].Link: val=<LDP1ResourceInteraction>; rel=profile
+                  
+              """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I3-S-URI> a tn:TestInput;
+    dc:description "The URI of an RDF resource.";
+    dc:title "<S URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I4-P-URI> a tn:TestInput;
+    dc:description "The URI of an RDF property.";
+    dc:title "<P URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ1-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title "<Response 1 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O2-Response-2-POST> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ2-POST-LDPC-URI>;
+    dc:description "The response of the POST request in step 2.";
+    dc:title "<Response 2 POST>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O3-Response-3-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ3-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 3.";
+    dc:title "<Response 3 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-O4-Response-4-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ4-GET-LOC-URI>;
+    dc:description "The response of the GET request in step 4.";
+    dc:title "<Response 4 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ4-TEST-CONTAINER> a tn:Step,
+        ht:Group;
+    dc:description "Pass TC-C9 (test created sub-container)" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O1-Response-1-GET>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 2xx
+                      [response-header].ETag exists
+                      [response-header].Link: val=<LDP1ResourceInteraction>; rel=profile
+                  
+              """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A2-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O1-Response-1-GET>;
+    dc:description """
+                  
+                      [message-body] contains <LDPC URI> rdf:type ldp:Container .
+                      [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+                      [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+                  
+              """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A3-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O1-Response-1-GET>;
+    dc:description """
+                  
+                      [message-body] does not contain <S URI> <P URI> <Response 2 POST>.[response-header].Location .
+                  
+              """;
+    dc:title "container does not have the to-be-created member" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A4-Response-2-POST> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O2-Response-2-POST>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 201
+                      [response-header].Location exists
+                      [response-header].Link: val=ldp:Resource; rel=profile
+                  
+              """;
+    dc:title "POST correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A5-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O3-Response-3-GET>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 2xx
+                      [response-header].ETag exists
+                      [response-header].Link: val=ldp:Resource; rel=profile
+                  
+              """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A6-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O3-Response-3-GET>;
+    dc:description """
+                  
+                      [message-body] contains <LDPC URI> rdf:type ldp:Container .
+                      [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+                      [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+                  
+              """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A7-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O3-Response-3-GET>;
+    dc:description """
+                  
+                      [message-body] contains <S URI> <P URI> <Response 2 POST>.[response-header].Location .
+                  
+              """;
+    dc:title "container has member" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-A8-Response-4-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC12-O4-Response-4-GET>;
+    dc:description """
+                  
+                      [Status-Line].Status-Code = 2xx
+                      [response-header].ETag exists
+                      [response-header].Link: val=<LDP1ResourceInteraction>; rel=profile
+                  
+              """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I3-S-URI> a tn:TestInput;
+    dc:description "The URI of an RDF resource.";
+    dc:title "<S URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I4-P-URI> a tn:TestInput;
+    dc:description "The URI of an RDF property.";
+    dc:title "<P URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ1-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title "<Response 1 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O2-Response-2-POST> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ2-POST-LDPC-URI>;
+    dc:description "The response of the POST request in step 2.";
+    dc:title "<Response 2 POST>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O3-Response-3-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ3-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 3.";
+    dc:title "<Response 3 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-O4-Response-4-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ4-GET-LOC-URI>;
+    dc:description "The response of the GET request in step 4.";
+    dc:title "<Response 4 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ4-TEST-CONTAINER> a tn:Step,
+        ht:Group;
+    dc:description "Fail TC-C9 step 2 (test that created object is NOT a container)" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC3-O1-Response-1-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 404 or 410
+          
+        """;
+    dc:title "GET incorrect" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-RQ1-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title "<Response 1 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-A1-Response-1-DELETE> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC6-O1-Response-1-DELETE>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "DELETE correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-A2-Response-1-DELETE> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC6-O1-Response-1-DELETE>;
+    dc:description """
+          
+            <Response 1 DELETE>.[Status-Line].Status-Code = 200 or 204 and <Response 2 GET>.[Status-Line].Status-Code = 404 or 410
+            or 
+            <Response 1 DELETE>.[Status-Line].Status-Code = 2xx (except 200 and 204)
+          
+        """;
+    dc:title "DELETE resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-O1-Response-1-DELETE> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-RQ1-DELETE-LDPC-URI>;
+    dc:description "The response of the DELETE request in step 1.";
+    dc:title "<Response 1 DELETE>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-O2-Response-2-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-RQ2-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 2.";
+    dc:title "<Response 2 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A1-Response-1-DELETE> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC7-O1-Response-1-DELETE>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "DELETE correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A2-Response-1-DELETE> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC7-O1-Response-1-DELETE>;
+    dc:description """
+          
+            <Response 1 DELETE>.[Status-Line].Status-Code = 200 or 204 and <Response 2 GET>.[Status-Line].Status-Code = 404 or 410
+            or 
+            <Response 1 DELETE>.[Status-Line].Status-Code = 2xx (except 200 and 204)
+          
+        """;
+    dc:title "DELETE resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A3-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC7-O3-Response-3-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A4-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC7-O3-Response-3-GET>;
+    dc:description """
+          
+            [message-body] contains <LDPC URI> rdf:type ldp:Container .
+            [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+            [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+          
+        """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-A5-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC7-O3-Response-3-GET>;
+    dc:description """
+          
+            [message-body] does not contain <S URI> <P URI> <LDPR URI> .
+          
+        """;
+    dc:title "member removed from container" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I3-S-URI> a tn:TestInput;
+    dc:description "The URI of an RDF resource.";
+    dc:title "<S URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I4-P-URI> a tn:TestInput;
+    dc:description "The URI of an RDF property.";
+    dc:title "<P URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-O1-Response-1-DELETE> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ1-DELETE-LDPR-URI>;
+    dc:description "The response of the DELETE request in step 1.";
+    dc:title "<Response 1 DELETE>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-O2-Response-2-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ2-GET-LDPR-URI>;
+    dc:description "The response of the GET request in step 2.";
+    dc:title "<Response 2 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-O3-Response-3-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ3-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 3.";
+    dc:title "<Response 3 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-A1-Response-1-HEAD> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC8-O1-Response-1-HEAD>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+            [message-body] not exists
+          
+        """;
+    dc:title "HEAD correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-O1-Response-1-HEAD> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-RQ1-HEAD-LDPC-URI>;
+    dc:description "The response of the HEAD request in step 1.";
+    dc:title "<Response 1 HEAD>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O1-Response-1-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A2-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O1-Response-1-GET>;
+    dc:description """
+          
+            [message-body] contains <LDPC URI> rdf:type ldp:Container .
+            [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+            [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+          
+        """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A3-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O1-Response-1-GET>;
+    dc:description """
+          
+            [message-body] does not contain <S URI> <P URI> <Response 2
+              POST>.[response-header].Location .
+          
+        """;
+    dc:title "container does not have member" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A4-Response-2-POST> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O2-Response-2-POST>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 201
+            [response-header].Location exists
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "POST correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A5-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O3-Response-3-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A6-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O3-Response-3-GET>;
+    dc:description """
+          
+            [message-body] contains <LDPC URI> rdf:type ldp:Container .
+            [message-body] contains <LDPC URI> ldp:membershipSubject <S URI> .
+            [message-body] contains <LDPC URI> ldp:membershipPredicate <P URI> . or <LDPC URI> ldp:membershipPredicateInverse <P URI> .
+          
+        """;
+    dc:title "GET container correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A7-Response-3-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O3-Response-3-GET>;
+    dc:description """
+          
+            [message-body] contains <S URI> <P URI> <Response 2 POST>.[response-header].Location .
+          
+        """;
+    dc:title "container has member" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-A8-Response-4-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCC9-O4-Response-4-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "GET resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I3-S-URI> a tn:TestInput;
+    dc:description "The URI of an RDF resource.";
+    dc:title "<S URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I4-P-URI> a tn:TestInput;
+    dc:description "The URI of an RDF property.";
+    dc:title "<P URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ1-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title "<Response 1 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O2-Response-2-POST> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ2-POST-LDPC-URI>;
+    dc:description "The response of the POST request in step 2.";
+    dc:title "<Response 2 POST>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O3-Response-3-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ3-GET-LDPC-URI>;
+    dc:description "The response of the GET request in step 3.";
+    dc:title "<Response 3 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-O4-Response-4-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ4-GET-LOC-URI>;
+    dc:description "The response of the GET request in step 4.";
+    dc:title "<Response 4 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCR1-O1-Response-1-GET>;
+    dc:description """
+            
+              [Status-Line].Status-Code = 2xx
+              [response-header].ETag exists
+              [response-header].Link = ldp:Resource; rel="type"
+            
+            """;
+    dc:title "GET correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-RQ1-GET-LDPR-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title """<Response
+ 1 GET>""" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-A1-Response-1-GET> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCR3-O1-Response-1-GET>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 404 or 410
+          
+          """;
+    dc:title "GET incorrect" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-O1-Response-1-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-RQ1-GET-LDPR-URI>;
+    dc:description "The response of the GET request in step 1.";
+    dc:title "<Response 1 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-A1-Response-1-DELETE> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCR6-O1-Response-1-DELETE>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].Link = ldp:Resource; rel="type"
+          
+        """;
+    dc:title "DELETE correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-A2-Response-1-DELETE> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCR6-O1-Response-1-DELETE>;
+    dc:description """
+          
+            <Response 1 DELETE>.[Status-Line].Status-Code = 200 or 204 and <Response 2 GET>.[Status-Line].Status-Code = 404 or 410
+            or 
+            <Response 1 DELETE>.[Status-Line].Status-Code = 2xx (except 200 and 204) 
+          
+        """;
+    dc:title "DELETE resource correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-O1-Response-1-DELETE> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-RQ1-DELETE-LDPR-URI>;
+    dc:description "The response of the DELETE request in step 1.";
+    dc:title "<Response 1 DELETE>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-O2-Response-2-GET> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-RQ2-GET-LDPR-URI>;
+    dc:description "The response of the GET request in step 2.";
+    dc:title "<Response 2 GET>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-A1-Response-1-HEAD> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCR7-O1-Response-1-HEAD>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx
+            [response-header].ETag exists
+            [response-header].Link = ldp:Resource; rel="type"
+            [message-body] not exists
+          
+        """;
+    dc:title "HEAD correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-O1-Response-1-HEAD> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-RQ1-HEAD-LDPR-URI>;
+    dc:description "The response of the HEAD request in step 1.";
+    dc:title "<Response 1 HEAD>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-A1-Response-1-OPTIONS> a tn:TestAssertion;
+    tn:outputAsserted <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/TCR8-O1-Response-1-OPTIONS>;
+    dc:description """
+          
+            [Status-Line].Status-Code = 2xx 
+            [entity-header].Allow exists
+          
+        """;
+    dc:title "OPTIONS correct" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-RP1-Response-1-OPTIONS> a tn:TestOutput,
+        ht:Response;
+    tn:fromStep <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-RQ1-OPTIONS-LDPR-URI>;
+    dc:description "The response of the OPTIONS request in step 1.";
+    dc:title "<Response 1 OPTIONS>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-RQ1-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC1-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-RQ1-OPTIONS-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC10-I1-LDPC-URI>;
+    dc:description """OPTIONS <LDPC URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I2-LDPC2-REP> a tn:TestInput;
+    dc:description "The representation of the nested LDPC to be created";
+    dc:title "<LDPC2 representation>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ1-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ2-POST-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I2-LDPC2-REP>;
+    dc:description """POST <LDPC URI>
+              
+                  [entity-header].Content-type = text/turtle
+                  [entity-header].Link: val=<LDP1ContainerInteraction>; rel=profile;
+                  [message-body] = <LDPC2 representation>
+              
+              """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ3-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-RQ4-GET-LOC-URI> a tn:Step,
+        ht:Request;
+    dc:description "GET <Response 2 POST>.[response-header].Location (location of created sub-container)" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I2-LDPC2-REP> a tn:TestInput;
+    dc:description "The representation of the nested LDPC to be created";
+    dc:title "<LDPC2 representation>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ1-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ2-POST-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I2-LDPC2-REP>;
+    dc:description """POST <LDPC URI>
+              
+                  [entity-header].Content-type = text/turtle
+                  [entity-header].Link: val=<LDP1ResourceInteraction> rel="profile"
+                  [message-body] = <LDPC2 representation>
+              
+              """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ3-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-RQ4-GET-LOC-URI> a tn:Step,
+        ht:Request;
+    dc:description "GET <Response 2 POST>.[response-header].Location (location of archived container)" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of a non-existing LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-RQ1-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC3-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-RQ1-DELETE-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-I1-LDPC-URI>;
+    dc:description """DELETE <LDPC URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-RQ2-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ1-DELETE-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I2-LDPR-URI>;
+    dc:description """DELETE <LDPR URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ2-GET-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I2-LDPR-URI>;
+    dc:description "GET <LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-RQ3-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-RQ1-HEAD-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC8-I1-LDPC-URI>;
+    dc:description """HEAD <LDPC URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I2-LDPR-REP> a tn:TestInput;
+    dc:description "The representation of the LDPR to be created";
+    dc:title "<LDPR representation>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ1-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ2-POST-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I1-LDPC-URI>,
+        <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I2-LDPR-REP>;
+    dc:description """POST <LDPC URI>
+          
+            [entity-header].Content-type = text/turtle
+            [message-body] = <LDPR representation>
+          
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ3-GET-LDPC-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I1-LDPC-URI>;
+    dc:description "GET <LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-RQ4-GET-LOC-URI> a tn:Step,
+        ht:Request;
+    dc:description "GET <Response 2 POST>.[response-header].Location" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-I1-LDPR-URI> a tn:TestInput;
+    dc:description "The URI of an LDPR.";
+    dc:title "<LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-RQ1-GET-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR1-I1-LDPR-URI>;
+    dc:description " GET <LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-I1-LDPR-URI> a tn:TestInput;
+    dc:description "The URI of a non-existing LDPR.";
+    dc:title "<LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-RQ1-GET-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR3-I1-LDPR-URI>;
+    dc:description "GET <LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-RQ1-DELETE-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-I1-LDPR-URI>;
+    dc:description """DELETE <LDPR URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-RQ2-GET-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-I1-LDPR-URI>;
+    dc:description "GET <LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-I1-LDPR-URI> a tn:TestInput;
+    dc:description "The URI of an LDPR.";
+    dc:title "<LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-RQ1-HEAD-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR7-I1-LDPR-URI>;
+    dc:description """HEAD <LDPR URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-I1-LDPR-URI> a tn:TestInput;
+    dc:description "The URI of an LDPR.";
+    dc:title "<LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-RQ1-OPTIONS-LDPR-URI> a tn:Step,
+        ht:Request;
+    tn:usesInput <https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR8-I1-LDPR-URI>;
+    dc:description """OPTIONS <LDPR URI>
+        """ .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC6-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC7-I2-LDPR-URI> a tn:TestInput;
+    dc:description "The URI of an LDPR that is a member of the LDPC.";
+    dc:title "<LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCR6-I1-LDPR-URI> a tn:TestInput;
+    dc:description "The URI of an LDPR.";
+    dc:title "<LDPR URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC11-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC12-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#TCC9-I1-LDPC-URI> a tn:TestInput;
+    dc:description "The URI of an LDPC.";
+    dc:title "<LDPC URI>" .
+
+td:unreviewed a td:ReviewStatus .
+
+<https://dvcs.w3.org/hg/ldpwg/raw-file/default/Test%20Cases/LDP%20Test%20Cases.html#RaulGarciaCastro> a foaf:Person;
+    rdfs:label "Eric Prud'hommeaux",
+        """Raúl 
+García-Castro""",
+        "Raúl García-Castro";
+    owl:sameAs <http://delicias.dia.fi.upm.es/%7Ergarcia/#me>,
+        <http://www.w3.org/People/Eric/ericP-foaf#ericP> .
diff --git a/platform/marmotta-ldp/src/test/java/org/apache/marmotta/platform/ldp/webservices/testsuite/LdpAbstractTestSuite.java b/platform/marmotta-ldp/src/test/java/org/apache/marmotta/platform/ldp/webservices/testsuite/LdpAbstractTestSuite.java
index 3d091f0..1a0b60d 100644
--- a/platform/marmotta-ldp/src/test/java/org/apache/marmotta/platform/ldp/webservices/testsuite/LdpAbstractTestSuite.java
+++ b/platform/marmotta-ldp/src/test/java/org/apache/marmotta/platform/ldp/webservices/testsuite/LdpAbstractTestSuite.java
@@ -49,6 +49,8 @@ public abstract class LdpAbstractTestSuite {
 
     public final static String FILES_PATH = "/testsuite/";
 
+    public final static String TEST_CASES_CACHE = "LDP-Test-Cases-WD-20140317";
+
     protected Repository repo;
 
     @Rule
@@ -57,7 +59,7 @@ public abstract class LdpAbstractTestSuite {
     @Before
     public final void before() throws RepositoryException, RDFParseException, IOException {
         log.info("initializing test case {}...", name.getMethodName());
-        repo = loadData(name.getMethodName());
+        repo = loadData(TEST_CASES_CACHE);
         Assume.assumeNotNull(repo);
     }
 
@@ -100,24 +102,24 @@ public abstract class LdpAbstractTestSuite {
      * Load a dataset to the connection passed
      *
      * @param conn connection
      * @param tc test case identifier
      * @throws RDFParseException
      * @throws RepositoryException
      * @throws IOException
      */
-    protected void loadData(RepositoryConnection conn, String tc) throws RDFParseException, RepositoryException, IOException {
-        log.debug("loading test case {}...", tc);
-        String path = FILES_PATH + "TC-" + tc + ".ttl";
+    protected void loadData(RepositoryConnection conn, String file) throws RDFParseException, RepositoryException, IOException {
+        log.debug("loading test cases {}...", file);
+        String path = FILES_PATH + file + ".ttl";
         InputStream is = getClass().getResourceAsStream(path);
         if (is == null) {
-            log.error("Data for test case {} not found where expected ({})", tc, path);
+            log.error("test cases data {} not found where expected ({})", file, path);
         } else {
             try {
                 conn.add(is, "", RDFFormat.TURTLE);
             } finally {
                 is.close();
             }
-            log.debug("data for test case {} successfully loaded", tc);
+            log.debug("test cases data {} successfully loaded ({} triples)", file, conn.size());
         }
     }
 
@@ -137,11 +139,11 @@ public abstract class LdpAbstractTestSuite {
                 try {
                     conn.setNamespace(value, key);
                 } catch (RepositoryException e) {
-                    log.error("Error adding namespace {}: {}", key, e.getMessage());
+                    log.error("error adding namespace {}: {}", key, e.getMessage());
                 }
             }
         } catch (IOException | NullPointerException e) {
-            log.error("Error loading normative namespaces at {}: {}", path, e.getMessage());
+            log.error("error loading normative namespaces at {}: {}", path, e.getMessage());
         }
 
     }

http://git-wip-us.apache.org/repos/asf/marmotta/blob/6490c9a9/platform/marmotta-ldp/src/test/resources/testsuite/LDP-Test-Cases-WD-20140317.ttl
----------------------------------------------------------------------
@@ -100,24 +102,24 @@ public abstract class LdpAbstractTestSuite {
      *
      * @param conn connection
-     * @param tc test case identifier
+     * @param file test case identifier
      * @throws RDFParseException
      * @throws RepositoryException